# harborapi.ext.report

`harborapi.ext.report` defines classes and functions for aggregating the data of multiple artifacts, including their repositories and vulnerability reports.

::: harborapi.ext.report
    options:
        merge_init_into_class: false
        show_if_no_docstring: false
        show_source: true
        show_bases: true
        <!-- members:
            - __init__ -->
